@@ -16,7 +16,7 @@ use overload (
     fallback => 1,
 );
 
-our $VERSION = '1.0.6';
+our $VERSION = '1.0.7';
 
 Readonly my $POS_INF => 2_147_483_647 - 1;             # INT_MAX - 1
 Readonly my $NEG_INF => ( -2_147_483_647 - 1 ) + 1;    # INT_MIN + 1
@@ -136,7 +136,12 @@ sub spans {
         push @spans, [ $lower, $upper ];
     }
 
-    return @spans;
+    if (@spans) {
+        return @spans;
+    }
+    else {
+        return;
+    }
 }
 
 sub sets {
@@ -150,7 +155,12 @@ sub sets {
         push @sets, blessed($self)->new("$lower-$upper");
     }
 
-    return @sets;
+    if (@sets) {
+        return @sets;
+    }
+    else {
+        return;
+    }
 }
 
 sub runlists {
@@ -169,7 +179,12 @@ sub runlists {
         push @runlists, $string;
     }
 
-    return @runlists;
+    if (@runlists) {
+        return @runlists;
+    }
+    else {
+        return;
+    }
 }
 
 sub cardinality {
@@ -409,6 +424,7 @@ sub subtract {
     return $self;
 }
 
+#@returns AlignDB::IntSpan
 sub copy {
     my $self = shift;
 
@@ -418,6 +434,7 @@ sub copy {
     return $copy;
 }
 
+#@returns AlignDB::IntSpan
 sub union {
     my $self = shift;
 
@@ -427,6 +444,7 @@ sub union {
     return $new;
 }
 
+#@returns AlignDB::IntSpan
 sub complement {
     my $self = shift;
 
@@ -436,6 +454,7 @@ sub complement {
     return $new;
 }
 
+#@returns AlignDB::IntSpan
 sub diff {
     my $self = shift;
 
@@ -447,6 +466,7 @@ sub diff {
     return $new;
 }
 
+#@returns AlignDB::IntSpan
 sub intersect {
     my $self = shift;
 
@@ -462,6 +482,8 @@ sub intersect {
     return $new;
 }
 
+#@method
+#@returns AlignDB::IntSpan
 sub xor {
     return intersect( union(@_), intersect(@_)->complement );
 }
@@ -606,6 +628,7 @@ sub index {
     return $index;
 }
 
+#@returns AlignDB::IntSpan
 sub slice {
     my $self = shift;
     my $from = shift;
@@ -910,6 +933,7 @@ sub distance {
     return $min_d;
 }
 
+#@returns AlignDB::IntSpan
 sub find_islands {
     my $self     = shift;
     my $supplied = shift;
@@ -959,6 +983,7 @@ sub _find_islands_set {
     return $islands;
 }
 
+#@returns AlignDB::IntSpan
 sub nearest_island {
     my $self     = shift;
     my $supplied = shift;
